@@ -378,7 +378,7 @@ def opa_graphql_decision(
 ) -> Callable[[str, OIDCUserModel], Coroutine[Any, Any, bool | None]]:
     async def _opa_decision(
         path: str,
-        oidc_user: OIDCUserModel,
+        oidc_user: OIDCUserModel = Depends(_oidc_security),
     ) -> bool | None:
         """
         Check OIDCUserModel against the OPA policy.
